@@ -18,7 +18,6 @@
  */
 
 #include <string>
-#include <sstream>
 #include <vector>
 
 #include <vulkan/vk_enum_string_helper.h>
@@ -109,7 +108,7 @@ private:
         }
         for (const auto &command : cb_state.GetLabelCommands()) {
             if (command.begin) {
-                cmdbuf_label_stack.push_back(command.label_name);
+                cmdbuf_label_stack.emplace_back(command.label_name);
             } else {
                 if (cmdbuf_label_stack.empty()) {
                     found_unbalanced_cmdbuf_label = true;
@@ -592,7 +591,7 @@ bool CoreChecks::ValidatePrimaryCommandBufferState(
     // Track in-use for resources off of primary and any secondary CBs
     bool skip = false;
 
-    if (cb_state.IsSeconary()) {
+    if (cb_state.IsSecondary()) {
         const auto &vuid = GetQueueSubmitVUID(loc, SubmitError::kSecondaryCmdInSubmit);
         skip |= LogError(vuid, cb_state.Handle(), loc, "Command buffer %s must be allocated with VK_COMMAND_BUFFER_LEVEL_PRIMARY.",
                          FormatHandle(cb_state).c_str());
@@ -667,8 +666,10 @@ bool CoreChecks::PreCallValidateQueueBindSparse(VkQueue queue, uint32_t bindInfo
                     ASSERT_AND_CONTINUE(buffer_state);
                     for (uint32_t buffer_bind_idx = 0; buffer_bind_idx < buffer_bind.bindCount; ++buffer_bind_idx) {
                         const VkSparseMemoryBind &memory_bind = buffer_bind.pBinds[buffer_bind_idx];
-                        const Location buffer_loc = bind_info_loc.dot(Field::pBufferBinds, buffer_idx);
-                        const Location bind_loc = buffer_loc.dot(Field::pBinds, buffer_bind_idx);
+                        const Location buffer_bind_info_loc = bind_info_loc.dot(Field::pBufferBinds, buffer_idx);
+                        const Location bind_loc = buffer_bind_info_loc.dot(Field::pBinds, buffer_bind_idx);
+                        skip |=
+                            ValidateBufferSparseMemoryBindAlignments(memory_bind, *buffer_state, bind_loc, buffer_bind_info_loc);
                         skip |=
                             ValidateSparseMemoryBind(memory_bind, buffer_state->requirements, buffer_state->requirements.size,
                                                      buffer_state->external_memory_handle_types, buffer_state->Handle(), bind_loc);
@@ -686,10 +687,11 @@ bool CoreChecks::PreCallValidateQueueBindSparse(VkQueue queue, uint32_t bindInfo
                     for (uint32_t image_opaque_bind_idx = 0; image_opaque_bind_idx < image_opaque_bind.bindCount;
                          ++image_opaque_bind_idx) {
                         const VkSparseMemoryBind &memory_bind = image_opaque_bind.pBinds[image_opaque_bind_idx];
-                        const Location image_loc = bind_info_loc.dot(Field::pImageOpaqueBinds, image_opaque_idx);
-                        const Location bind_loc = image_loc.dot(Field::pBinds, image_opaque_bind_idx);
+                        const Location image_bind_info_loc = bind_info_loc.dot(Field::pImageOpaqueBinds, image_opaque_idx);
+                        const Location bind_loc = image_bind_info_loc.dot(Field::pBinds, image_opaque_bind_idx);
                         // Assuming that no multiplanar disjointed images are possible with sparse memory binding. Needs
                         // confirmation
+                        skip |= ValidateImageSparseMemoryBindAlignments(memory_bind, *image_state, bind_loc, image_bind_info_loc);
                         skip |=
                             ValidateSparseMemoryBind(memory_bind, image_state->requirements[0], image_state->requirements[0].size,
                                                      image_state->external_memory_handle_types, image_state->Handle(), bind_loc);
