@@ -51,8 +51,8 @@ TEST_F(PositiveVideo, MultipleCmdBufs) {
     context.CreateResources();
 
     vkt::CommandPool cmd_pool(*m_device, config.QueueFamilyIndex(), VK_COMMAND_POOL_CREATE_RESET_COMMAND_BUFFER_BIT);
-    vkt::CommandBuffer cb1(*m_device, &cmd_pool, VK_COMMAND_BUFFER_LEVEL_PRIMARY, &context.Queue());
-    vkt::CommandBuffer cb2(*m_device, &cmd_pool, VK_COMMAND_BUFFER_LEVEL_PRIMARY, &context.Queue());
+    vkt::CommandBuffer cb1(*m_device, cmd_pool, VK_COMMAND_BUFFER_LEVEL_PRIMARY);
+    vkt::CommandBuffer cb2(*m_device, cmd_pool, VK_COMMAND_BUFFER_LEVEL_PRIMARY);
 
     cb1.begin();
     cb1.BeginVideoCoding(context.Begin());
@@ -67,9 +67,39 @@ TEST_F(PositiveVideo, MultipleCmdBufs) {
     cb2.EndVideoCoding(context.End());
     cb2.end();
 
-    vkt::Fence fence{};
-    context.Queue().submit({&cb1, &cb2}, fence, true);
-    m_device->wait();
+    std::array cbs = {&cb1, &cb2};
+    context.Queue().Submit(cbs);
+    m_device->Wait();
+}
+
+TEST_F(PositiveVideo, BeginCodingOutOfBoundsSlotIndex) {
+    TEST_DESCRIPTION("vkCmdBeginCodingKHR - referenced DPB slot index is invalid but it should not cause submit time crash");
+
+    RETURN_IF_SKIP(Init());
+
+    VideoConfig config = GetConfig(GetConfigsWithReferences(GetConfigs(), 4));
+    if (!config) {
+        GTEST_SKIP() << "Test requires a video profile with support for 4 reference pictures";
+    }
+
+    config.SessionCreateInfo()->maxDpbSlots = 3;
+    config.SessionCreateInfo()->maxActiveReferencePictures = 3;
+
+    VideoContext context(m_device, config);
+    context.CreateAndBindSessionMemory();
+    context.CreateResources();
+
+    vkt::CommandBuffer& cb = context.CmdBuffer();
+
+    cb.begin();
+    m_errorMonitor->SetAllowedFailureMsg("VUID-VkVideoBeginCodingInfoKHR-slotIndex-04856");
+    m_errorMonitor->SetAllowedFailureMsg("VUID-vkCmdBeginVideoCodingKHR-slotIndex-07239");
+    cb.BeginVideoCoding(context.Begin().AddResource(-1, 0).AddResource(3, 1).AddResource(-1, 2));
+    cb.EndVideoCoding(context.End());
+    cb.end();
+
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, VideoDecodeProfileIndependentResources) {
@@ -168,8 +198,8 @@ TEST_F(PositiveVideo, VideoDecodeH264) {
     cb.DecodeVideo(context.DecodeReferenceFrame(2).AddReferenceFrame(0));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(context.Begin().AddResource(0, 0).InvalidateSlot(1).AddResource(-1, 1).AddResource(2, 2));
@@ -178,8 +208,8 @@ TEST_F(PositiveVideo, VideoDecodeH264) {
     cb.DecodeVideo(context.DecodeReferenceFrame(2).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, VideoDecodeH264Interlaced) {
@@ -216,8 +246,8 @@ TEST_F(PositiveVideo, VideoDecodeH264Interlaced) {
     cb.DecodeVideo(context.DecodeReferenceFrame(1).AddReferenceBothFields(0));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(context.Begin().InvalidateSlot(0).AddResource(-1, 0).AddResource(1, 1));
@@ -226,8 +256,8 @@ TEST_F(PositiveVideo, VideoDecodeH264Interlaced) {
     cb.DecodeVideo(context.DecodeFrame(1).AddReferenceFrame(0));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, VideoDecodeH264InterlacedPartialInvalidation) {
@@ -263,8 +293,8 @@ TEST_F(PositiveVideo, VideoDecodeH264InterlacedPartialInvalidation) {
     cb.DecodeVideo(context.DecodeReferenceFrame(1).AddReferenceTopField(0));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(context.Begin().AddResource(0, 0).AddResource(1, 1).AddResource(-1, 2));
@@ -273,8 +303,8 @@ TEST_F(PositiveVideo, VideoDecodeH264InterlacedPartialInvalidation) {
     cb.DecodeVideo(context.DecodeFrame(0).AddReferenceBottomField(2));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, VideoDecodeH265) {
@@ -312,8 +342,8 @@ TEST_F(PositiveVideo, VideoDecodeH265) {
     cb.DecodeVideo(context.DecodeReferenceFrame(2).AddReferenceFrame(0).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(context.Begin().AddResource(0, 0).InvalidateSlot(1).AddResource(-1, 1).AddResource(2, 2));
@@ -322,8 +352,8 @@ TEST_F(PositiveVideo, VideoDecodeH265) {
     cb.DecodeVideo(context.DecodeFrame(2).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, VideoDecodeAV1) {
@@ -360,8 +390,8 @@ TEST_F(PositiveVideo, VideoDecodeAV1) {
     cb.DecodeVideo(context.DecodeReferenceFrame(2).AddReferenceFrame(0).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(context.Begin().AddResource(0, 0).InvalidateSlot(1).AddResource(-1, 1).AddResource(2, 2));
@@ -370,8 +400,8 @@ TEST_F(PositiveVideo, VideoDecodeAV1) {
     cb.DecodeVideo(context.DecodeFrame(2).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, DecodeAV1DistinctWithFilmGrain) {
@@ -475,8 +505,8 @@ TEST_F(PositiveVideo, VideoEncodeH264) {
     cb.EncodeVideo(context.EncodeReferenceFrame(2).AddReferenceFrame(0));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(
@@ -486,8 +516,8 @@ TEST_F(PositiveVideo, VideoEncodeH264) {
     cb.EncodeVideo(context.EncodeFrame(2).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, VideoEncodeH265) {
@@ -535,8 +565,8 @@ TEST_F(PositiveVideo, VideoEncodeH265) {
     cb.EncodeVideo(context.EncodeReferenceFrame(2).AddReferenceFrame(0).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 
     cb.begin();
     cb.BeginVideoCoding(
@@ -546,8 +576,8 @@ TEST_F(PositiveVideo, VideoEncodeH265) {
     cb.EncodeVideo(context.EncodeFrame(2).AddReferenceFrame(1));
     cb.EndVideoCoding(context.End());
     cb.end();
-    context.Queue().submit(cb);
-    m_device->wait();
+    context.Queue().Submit(cb);
+    m_device->Wait();
 }
 
 TEST_F(PositiveVideo, EncodeRateControlH264LayerCount) {
